@@ -2,9 +2,7 @@ package Reply::Plugin::Timer;
 BEGIN {
   $Reply::Plugin::Timer::AUTHORITY = 'cpan:DOY';
 }
-{
-  $Reply::Plugin::Timer::VERSION = '0.34';
-}
+$Reply::Plugin::Timer::VERSION = '0.35';
 use strict;
 use warnings;
 # ABSTRACT: time commands
@@ -29,7 +27,7 @@ sub execute {
     my ($self, $next, @args) = @_;
 
     my $t0 = [gettimeofday];
-    my $ret = $next->(@args);
+    my @ret = $next->(@args);
     my $elapsed = tv_interval($t0);
 
     if ($elapsed > $self->{mintime}) {
@@ -40,7 +38,7 @@ sub execute {
         }
     }
 
-    return $ret;
+    return @ret;
 }
 
 1;
@@ -49,13 +47,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Reply::Plugin::Timer - time commands
 
 =head1 VERSION
 
-version 0.34
+version 0.35
 
 =head1 SYNOPSIS
 
@@ -74,7 +74,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Jesse Luehrs.
+This software is Copyright (c) 2014 by Jesse Luehrs.
 
 This is free software, licensed under:
 
